/*  $Id: Logger.java 1188 2011-08-28 11:43:31Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2010 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package net.eduvax.util;

import java.util.Properties;
import java.util.logging.ConsoleHandler;
import java.util.logging.Level;

/**
 * Simple Logger based upon log4j.
 * @author Sebastien Devaux
 * @version $Id: Logger.java 1188 2011-08-28 11:43:31Z sdevaux $
 */
public class Logger implements SLogger {
    /**
     * get named logger.
     * @param name logger's name. Should be logger creator package name.
     * @return the logger
     */
    public static SLogger getSLogger(String name) {
        return getSLogger(name,System.getProperties());    
    }       
    /**
     * get named logger with special configuration.
     * @param name logger's name
     * @param prop logger configuration
     */ 
    public static SLogger getSLogger(String name,Properties prop) {
        return new Logger(name,prop);
    }    
    //------------------------------------------------------------
    // SLogger implementation
    public void debug(Object message) {
        _logger.log(Level.FINER,""+message);
    }    
    public void info(Object message) {
        _logger.log(Level.INFO,""+message);
    }    
    public void warn(Object message) {
        _logger.log(Level.WARNING,""+message);
    }    
    public void error(Object message) {
        _logger.log(Level.SEVERE,""+message);
    }    
    public void fatal(Object message) {
        _logger.log(Level.SEVERE,"FATAL:"+message);
    }    
    /**
     * Create new named logger.
     * @param name logger name.
     */
    public Logger(String name,Properties prop) {
        _logger=java.util.logging.Logger.getLogger("net.eduvax.util"); 
        _logger.setLevel(Level.ALL);
    }  

    static public void init() {
        // stop root logger 
        java.util.logging.Logger root=java.util.logging.Logger.getLogger("");
        while (root.getHandlers().length>0) {
            root.removeHandler(root.getHandlers()[0]);
        }
        ConsoleHandler ch=new ConsoleHandler();
        ch.setLevel(Level.ALL);
        ch.setFormatter(new LogFormatter());
        root.addHandler(ch);
    }
    /** delegated java logger */
    private java.util.logging.Logger _logger;
}
